<template>
  <div>
    <list-condition-template ref="table" :form="listQuery" :formLabel="formLabel" dataKey="id"
                             :tableData="tableData" :total="total"
                             @page-info-change="handlePageInfoChange">
      <template slot="otherElement">
        <el-form-item>
          <el-button size="mini" type="primary" @click="queryData">查询</el-button>
          <el-button size="mini" @click="resetQuery">重置</el-button>
        </el-form-item>
      </template>
      <template slot="columns">
        <el-table-column label="商品主编码" prop="spuNum" show-overflow-tooltip></el-table-column>
        <el-table-column label="商品名称" prop="spuName" show-overflow-tooltip></el-table-column>
        <el-table-column label="规格" prop="spec" show-overflow-tooltip></el-table-column>
        <el-table-column label="红线价" width="180px">
          <template slot-scope="scope">
            {{ scope.row.redLinePrice && scope.row.redLinePrice !== null ? '￥' + scope.row.redLinePrice.toFixed(2) : '-' }}
          </template>
        </el-table-column>
        <el-table-column label="操作" :width="`${$store.getters.colSize + 30}px`">
          <template slot-scope="scope">
            <wly-btn @click="detailsInfo(scope.row,scope.$index)">详情</wly-btn>
          </template>
        </el-table-column>
      </template>
    </list-condition-template>
    <price-management-info ref="priceManagementInfo" :row="rowData" @submit="onSubmit">
    </price-management-info>
  </div>
</template>
<script>
import priceManagementApi from '@/api/priceManagement'
import priceManagementInfo from './info.vue'
export default {
  components: { priceManagementInfo },
  data () {
    return {
      tableData: [],
      total: 0,
      listQuery: {
        spuNum: null,
        spuName: null
      },
      formLabel: [
        {
          model: 'spuNum',
          label: '商品主编码',
          type: 'input',
          labelWidth: '100px',
          rule: /[^\w]/g // 可输入数字字母
        },
        {
          model: 'spuName',
          label: '商品名称',
          type: 'input'
        }
      ],
      rowData: null
    }
  },
  /*
   * 数据变化后刷新列表
 */
  activated () {
    this.queryList(this.$refs.table.getPageInfo())
  },
  methods: {
    /**
   * 详情
   */
    detailsInfo (row, index) {
      this.$refs.priceManagementInfo.toggleDialog()
      this.rowData = row
    },
    /**
     * '分页信息改变时查询列表
     */
    handlePageInfoChange (pageInfo) {
      this.queryList(pageInfo)
    },

    /**
   * 重置
   */
    resetQuery () {
      this.$refs.table.reloadCurrent()
    },
    /**
   * 点击查询按钮
   */
    queryData () {
      this.$refs.table.changeCondition()
    },
    /**
   * 查询列表
   */
    async queryList (pageInfo = { pageNum: 1, pageSize: 10 }) {
      try {
        const res = await priceManagementApi.getList({ ...this.listQuery, current: pageInfo.pageNum, size: pageInfo.pageSize })
        if (res.code === '200') {
          this.tableData = res.data.records
          this.total = res.data.total
        }
      } catch (error) {
      }
    },
    /**
* 价格调整成功操作
*/
    onSubmit () {
      this.queryData()
    }
  }
}
</script>
